@@ -11,16 +11,18 @@ class Form82(Form8x):
         if os.path.isdir(_code_dir):
             self.form = helper.json_read(_code_dir, 'form.json')
             self.code['obj'] = helper.txt_read(_code_dir, 'module.txt')
+            self.header[f'code_info_obj'] = 1
 
     def decode_data(self, src_dir, uuid):
         pass
 
     def write_encode_object(self, dest_dir):
-        form_dir = os.path.join(dest_dir, f'{self.header["uuid"]}.0')
-        os.makedirs(form_dir, exist_ok=True)
         helper.json_write(self.encode_header(), dest_dir, f'{self.header["uuid"]}.json')
-        helper.json_write(self.form, form_dir, 'form.json')
-        helper.txt_write(self.code['obj'], form_dir, 'module.txt')
+        if self.header.get('code_info_obj'):
+            _code_dir = f'{os.path.join(dest_dir, self.header["uuid"])}.0'
+            os.makedirs(_code_dir, exist_ok=True)
+            helper.json_write(self.form, _code_dir, 'form.json')
+            helper.txt_write(self.code['obj'], _code_dir, 'module.txt')
 
     def encode_header(self):
         return [[
@@ -945,3 +947,6 @@ class Form82(Form8x):
             "1",
             "1"
         ]]
+
+    def encode_data(self):
+        pass
